==> kubernetes-model-admissionregistration-5.3.0-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1beta1/RuleFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1beta1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface RuleFluent<A extends io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleFluent<A>> extends Fluent<A> {


    public A addToApiGroups(int index,String item);
    public A setToApiGroups(int index,String item);
    public A addToApiGroups(String... items);
    public A addAllToApiGroups(Collection<String> items);
    public A removeFromApiGroups(String... items);
    public A removeAllFromApiGroups(Collection<String> items);
    public List<String> getApiGroups();
    public String getApiGroup(int index);
    public String getFirstApiGroup();
    public String getLastApiGroup();
    public String getMatchingApiGroup(Predicate<String> predicate);
    public Boolean hasMatchingApiGroup(Predicate<String> predicate);
    public A withApiGroups(List<String> apiGroups);
    public A withApiGroups(String... apiGroups);
    public Boolean hasApiGroups();
    public A addNewApiGroup(StringBuilder arg1);
    public A addNewApiGroup(int[] arg1,int arg2,int arg3);
    public A addNewApiGroup(char[] arg1);
    public A addNewApiGroup(StringBuffer arg1);
    public A addNewApiGroup(byte[] arg1,int arg2);
    public A addNewApiGroup(byte[] arg1);
    public A addNewApiGroup(char[] arg1,int arg2,int arg3);
    public A addNewApiGroup(byte[] arg1,int arg2,int arg3);
    public A addNewApiGroup(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewApiGroup(String arg1);
    public A addToApiVersions(int index,String item);
    public A setToApiVersions(int index,String item);
    public A addToApiVersions(String... items);
    public A addAllToApiVersions(Collection<String> items);
    public A removeFromApiVersions(String... items);
    public A removeAllFromApiVersions(Collection<String> items);
    public List<String> getApiVersions();
    public String getApiVersion(int index);
    public String getFirstApiVersion();
    public String getLastApiVersion();
    public String getMatchingApiVersion(Predicate<String> predicate);
    public Boolean hasMatchingApiVersion(Predicate<String> predicate);
    public A withApiVersions(List<String> apiVersions);
    public A withApiVersions(String... apiVersions);
    public Boolean hasApiVersions();
    public A addNewApiVersion(StringBuilder arg1);
    public A addNewApiVersion(int[] arg1,int arg2,int arg3);
    public A addNewApiVersion(char[] arg1);
    public A addNewApiVersion(StringBuffer arg1);
    public A addNewApiVersion(byte[] arg1,int arg2);
    public A addNewApiVersion(byte[] arg1);
    public A addNewApiVersion(char[] arg1,int arg2,int arg3);
    public A addNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A addNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewApiVersion(String arg1);
    public A addToResources(int index,String item);
    public A setToResources(int index,String item);
    public A addToResources(String... items);
    public A addAllToResources(Collection<String> items);
    public A removeFromResources(String... items);
    public A removeAllFromResources(Collection<String> items);
    public List<String> getResources();
    public String getResource(int index);
    public String getFirstResource();
    public String getLastResource();
    public String getMatchingResource(Predicate<String> predicate);
    public Boolean hasMatchingResource(Predicate<String> predicate);
    public A withResources(List<String> resources);
    public A withResources(String... resources);
    public Boolean hasResources();
    public A addNewResource(StringBuilder arg1);
    public A addNewResource(int[] arg1,int arg2,int arg3);
    public A addNewResource(char[] arg1);
    public A addNewResource(StringBuffer arg1);
    public A addNewResource(byte[] arg1,int arg2);
    public A addNewResource(byte[] arg1);
    public A addNewResource(char[] arg1,int arg2,int arg3);
    public A addNewResource(byte[] arg1,int arg2,int arg3);
    public A addNewResource(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewResource(String arg1);
    public String getScope();
    public A withScope(String scope);
    public Boolean hasScope();
    public A withNewScope(StringBuilder arg1);
    public A withNewScope(int[] arg1,int arg2,int arg3);
    public A withNewScope(char[] arg1);
    public A withNewScope(StringBuffer arg1);
    public A withNewScope(byte[] arg1,int arg2);
    public A withNewScope(byte[] arg1);
    public A withNewScope(char[] arg1,int arg2,int arg3);
    public A withNewScope(byte[] arg1,int arg2,int arg3);
    public A withNewScope(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewScope(String arg1);
}

==> kubernetes-model-admissionregistration-5.3.1-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1beta1/RuleFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1beta1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface RuleFluent<A extends io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public A addToApiGroups(int index,String item);
    public A setToApiGroups(int index,String item);
    public A addToApiGroups(String... items);
    public A addAllToApiGroups(Collection<String> items);
    public A removeFromApiGroups(String... items);
    public A removeAllFromApiGroups(Collection<String> items);
    public List<String> getApiGroups();
    public String getApiGroup(int index);
    public String getFirstApiGroup();
    public String getLastApiGroup();
    public String getMatchingApiGroup(Predicate<String> predicate);
    public Boolean hasMatchingApiGroup(Predicate<String> predicate);
    public A withApiGroups(List<String> apiGroups);
    public A withApiGroups(String... apiGroups);
    public Boolean hasApiGroups();
    public A addNewApiGroup(StringBuilder arg1);
    public A addNewApiGroup(int[] arg1,int arg2,int arg3);
    public A addNewApiGroup(char[] arg1);
    public A addNewApiGroup(StringBuffer arg1);
    public A addNewApiGroup(byte[] arg1,int arg2);
    public A addNewApiGroup(byte[] arg1);
    public A addNewApiGroup(char[] arg1,int arg2,int arg3);
    public A addNewApiGroup(byte[] arg1,int arg2,int arg3);
    public A addNewApiGroup(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewApiGroup(String arg1);
    public A addToApiVersions(int index,String item);
    public A setToApiVersions(int index,String item);
    public A addToApiVersions(String... items);
    public A addAllToApiVersions(Collection<String> items);
    public A removeFromApiVersions(String... items);
    public A removeAllFromApiVersions(Collection<String> items);
    public List<String> getApiVersions();
    public String getApiVersion(int index);
    public String getFirstApiVersion();
    public String getLastApiVersion();
    public String getMatchingApiVersion(Predicate<String> predicate);
    public Boolean hasMatchingApiVersion(Predicate<String> predicate);
    public A withApiVersions(List<String> apiVersions);
    public A withApiVersions(String... apiVersions);
    public Boolean hasApiVersions();
    public A addNewApiVersion(StringBuilder arg1);
    public A addNewApiVersion(int[] arg1,int arg2,int arg3);
    public A addNewApiVersion(char[] arg1);
    public A addNewApiVersion(StringBuffer arg1);
    public A addNewApiVersion(byte[] arg1,int arg2);
    public A addNewApiVersion(byte[] arg1);
    public A addNewApiVersion(char[] arg1,int arg2,int arg3);
    public A addNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A addNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewApiVersion(String arg1);
    public A addToResources(int index,String item);
    public A setToResources(int index,String item);
    public A addToResources(String... items);
    public A addAllToResources(Collection<String> items);
    public A removeFromResources(String... items);
    public A removeAllFromResources(Collection<String> items);
    public List<String> getResources();
    public String getResource(int index);
    public String getFirstResource();
    public String getLastResource();
    public String getMatchingResource(Predicate<String> predicate);
    public Boolean hasMatchingResource(Predicate<String> predicate);
    public A withResources(List<String> resources);
    public A withResources(String... resources);
    public Boolean hasResources();
    public A addNewResource(StringBuilder arg1);
    public A addNewResource(int[] arg1,int arg2,int arg3);
    public A addNewResource(char[] arg1);
    public A addNewResource(StringBuffer arg1);
    public A addNewResource(byte[] arg1,int arg2);
    public A addNewResource(byte[] arg1);
    public A addNewResource(char[] arg1,int arg2,int arg3);
    public A addNewResource(byte[] arg1,int arg2,int arg3);
    public A addNewResource(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewResource(String arg1);
    public String getScope();
    public A withScope(String scope);
    public Boolean hasScope();
    public A withNewScope(StringBuilder arg1);
    public A withNewScope(int[] arg1,int arg2,int arg3);
    public A withNewScope(char[] arg1);
    public A withNewScope(StringBuffer arg1);
    public A withNewScope(byte[] arg1,int arg2);
    public A withNewScope(byte[] arg1);
    public A withNewScope(char[] arg1,int arg2,int arg3);
    public A withNewScope(byte[] arg1,int arg2,int arg3);
    public A withNewScope(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewScope(String arg1);
}
